@@ -16,3 +16,18 @@ TERMINAL_INTEGRATED = "integrated"
 TERMINAL_EXTERNAL = "external"
 
 VALID_TERMINAL_OPTIONS = [TERMINAL_NONE, TERMINAL_INTEGRATED, TERMINAL_EXTERNAL]
+
+
+STATE_RUNNING = "running"
+STATE_PAUSED = "paused"
+
+# See: StoppedEvent
+REASON_BREAKPOINT = "breakpoint"
+REASON_STEP = "step"
+REASON_PAUSE = "pause"
+
+STEP_IN = "step_in"
+STEP_NEXT = "step_next"
+
+
+MAIN_THREAD_ID = 1
