@@ -1,8 +1,8 @@
 import ast as ast_module
-from robotframework_ls.lsp import Error
+from robocode_ls_core.lsp import Error
 import sys
 from collections import namedtuple
-from robotframework_ls.robotframework_log import get_logger
+from robocode_ls_core.robotframework_log import get_logger
 
 log = get_logger(__name__)
 
@@ -362,7 +362,7 @@ def iter_keyword_usage_tokens(ast):
     :note: this goes hand-in-hand with get_keyword_name_token.
     """
     from robot.api import Token
-    from robotframework_ls._utils import isinstance_name
+    from robocode_ls_core.basic import isinstance_name
 
     for stack, node in _iter_nodes(ast, recursive=True):
         if node.__class__.__name__ == "KeywordCall":
@@ -381,7 +381,7 @@ def get_keyword_name_token(ast, token):
     """
     :note: this goes hand-in-hand with iter_keyword_usage_tokens.
     """
-    from robotframework_ls._utils import isinstance_name
+    from robocode_ls_core.basic import isinstance_name
 
     if token.type == token.KEYWORD or (
         token.type == token.NAME and isinstance_name(ast, ("Fixture", "TestTemplate"))
