@@ -21,15 +21,15 @@ def robot_source_format(source, space_count=4):
 
 
 def _create_range(d, offset1, offset2):
-    from robotframework_ls.lsp import Range
+    from robocode_ls_core.lsp import Range
 
     return Range(d.offset_to_line_col(offset1), d.offset_to_line_col(offset2))
 
 
 def create_text_edit_from_diff(contents, new_contents):
     from difflib import SequenceMatcher
-    from robotframework_ls.lsp import TextEdit
-    from robotframework_ls.workspace import Document
+    from robocode_ls_core.lsp import TextEdit
+    from robocode_ls_core.workspace import Document
 
     d = Document("", contents)
 
