@@ -1,5 +1,4 @@
-from robotframework_ls.client_base import LanguageServerClientBase
-from robotframework_ls.options import USE_TIMEOUTS, NO_TIMEOUT
+from robocode_ls_core.client_base import LanguageServerClientBase
 
 
 class SubprocessDiedError(Exception):
@@ -27,6 +26,8 @@ class RobotFrameworkApiClient(LanguageServerClientBase):
     def initialize(
         self, msg_id=None, process_id=None, root_uri="", workspace_folders=()
     ):
+        from robocode_ls_core.options import NO_TIMEOUT, USE_TIMEOUTS
+
         self._check_process_alive()
         msg_id = msg_id if msg_id is not None else self.next_id()
         return self.request(
